summaryrefslogtreecommitdiff
path: root/ace/Select_Reactor_T.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1998-10-14 21:45:15 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1998-10-14 21:45:15 +0000
commite150ebbecf9525a47a1a144fe202a2f83b396c39 (patch)
tree9d4be762e03bbb102e7255a87956c2dea7c5bda7 /ace/Select_Reactor_T.h
parent62cac453b72e681ac9df6e7685bece40a6427878 (diff)
downloadATCD-e150ebbecf9525a47a1a144fe202a2f83b396c39.tar.gz
.
Diffstat (limited to 'ace/Select_Reactor_T.h')
-rw-r--r--ace/Select_Reactor_T.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/ace/Select_Reactor_T.h b/ace/Select_Reactor_T.h
index d2ccf5f06be..60a478adc41 100644
--- a/ace/Select_Reactor_T.h
+++ b/ace/Select_Reactor_T.h
@@ -19,8 +19,9 @@
#include "ace/Select_Reactor_Base.h"
-// Forward declaration.
-//template class ACE_Select_Reactor_T<cla
+#if !defined (ACE_LACKS_PRAGMA_ONCE)
+#pragma once
+#endif /* ACE_LACKS_PRAGMA_ONCE */
template <class ACE_SELECT_REACTOR_MUTEX>
class ACE_Select_Reactor_Token_T : public ACE_SELECT_REACTOR_MUTEX
@@ -165,9 +166,9 @@ public:
// application wishes to handle events for some fixed amount of
// time.
//
- // Returns the total number of <ACE_Event_Handler>s that were
- // dispatched, 0 if the <max_wait_time> elapsed without dispatching
- // any handlers, or -1 if something goes wrong.
+ // Returns the total number of I/O and Timer <ACE_Event_Handler>s
+ // that were dispatched, 0 if the <max_wait_time> elapsed without
+ // dispatching any handlers, or -1 if something goes wrong.
//
// Current <alertable_handle_events> is identical to
// <handle_events>.
@@ -529,10 +530,11 @@ protected:
// of <ACE_Event_Handler>s that were dispatched or -1 if something
// goes wrong.
- virtual int dispatch_timer_handlers (void);
- // Dispatch any expired timer handlers. Returns -1 if the state of
- // the <wait_set_> has changed, else returns number of timer
- // handlers dispatched.
+ virtual int dispatch_timer_handlers (int &number_dispatched);
+ // Dispatch all timer handlers that have expired. Returns -1 if the
+ // state of the <wait_set_> has changed, else 0.
+ // <number_dispatched> is set to the number of timer handlers
+ // dispatched.
virtual int dispatch_notification_handlers (int &number_of_active_handles,
ACE_Select_Reactor_Handle_Set &dispatch_set);